@@ -9,8 +9,9 @@ from edalize.edatool import Edatool
 
 logger = logging.getLogger(__name__)
 
+
 class Morty(Edatool):
-    argtypes = ['cmdlinearg', 'vlogdefine']
+    argtypes = ["cmdlinearg", "vlogdefine"]
 
     _description = """ Morty Systemverilog pickle
 
@@ -33,28 +34,35 @@ Get `morty` from here: https://github.com/zarubaf/morty
 """
 
     tool_options = {
-        'lists' : {
-            'morty_options' : 'String', # runtime options (passed to morty)
+        "lists": {
+            "morty_options": "String",  # runtime options (passed to morty)
         }
     }
 
     @classmethod
     def get_doc(cls, api_ver):
         if api_ver == 0:
-            return {'description' : "Run the (System-) Verilog pickle tool called `morty`.",
-                    'lists' : [
-                        {'name' : 'morty_options',
-                         'type' : 'String',
-                         'desc' : 'Run-time options passed to morty.'},
-                        ]}
+            return {
+                "description": "Run the (System-) Verilog pickle tool called `morty`.",
+                "lists": [
+                    {
+                        "name": "morty_options",
+                        "type": "String",
+                        "desc": "Run-time options passed to morty.",
+                    },
+                ],
+            }
 
     def build_main(self, target=None):
         args = list()
         src_files_filtered = list()
         (src_files, incdirs) = self._get_fileset_files()
 
-        args += ['-I {}'.format(incdir) for incdir in incdirs]
-        args += ['-D {}={}'.format(key, self._param_value_str(value)) for key, value in self.vlogdefine.items()]
+        args += ["-I {}".format(incdir) for incdir in incdirs]
+        args += [
+            "-D {}={}".format(key, self._param_value_str(value))
+            for key, value in self.vlogdefine.items()
+        ]
 
         # Filter for Verilog source files.
         for src_file in src_files:
@@ -64,9 +72,9 @@ Get `morty` from here: https://github.com/zarubaf/morty
         # Append filtered file names.
         args += [f.name for f in src_files_filtered]
         # Append any options passed through `morty_options`.
-        args += self.tool_options.get('morty_options', [])
+        args += self.tool_options.get("morty_options", [])
         # Go and do your thing!
-        self._run_tool('morty', args, quiet=True)
+        self._run_tool("morty", args, quiet=True)
 
     def run_main(self):
         logger.warn("Morty does not support running. Use build instead.")
